@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,6 +19,7 @@
 
 #include "externalcomposerconfigurewidgettest.h"
 #include "../externalcomposerconfigurewidget.h"
+#include "kdepimtest_layout.h"
 #include <QCheckBox>
 #include <QVBoxLayout>
 #include <QLabel>
@@ -37,7 +38,7 @@ void ExternalComposerConfigureWidgetTest::shouldHaveDefaultValues()
     ExternalComposerConfigureWidget w(nullptr);
     QVBoxLayout *vboxlayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(vboxlayout);
-    QCOMPARE(vboxlayout->margin(), 0);
+    KdepimTestLayout::checkContentsMargins(0, vboxlayout);
 
     QCheckBox *mExternalEditorCheck = w.findChild<QCheckBox *>(QStringLiteral("enabled"));
     QVERIFY(mExternalEditorCheck);
