@@ -40,16 +40,16 @@ ShareTextPluginEditorInterface::~ShareTextPluginEditorInterface()
 void ShareTextPluginEditorInterface::createAction(KActionCollection *ac)
 {
     SharetextPurposeMenuWidget *purposeMenu = new SharetextPurposeMenuWidget(parentWidget(), this);
+    QAction *shareAction = new QAction(i18n("Share Mail Text..."), this);
+    shareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    ac->addAction(QStringLiteral("share_text_menu"), shareAction);
+    purposeMenu->setEditorWidget(this);
+    MessageComposer::PluginActionType type(shareAction, MessageComposer::PluginActionType::File);
+    setActionType(type);
     if (purposeMenu->menu()) {
-        QAction *shareAction = new QAction(i18n("Share Mail Text..."), this);
         shareAction->setMenu(purposeMenu->menu());
-        shareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
-        ac->addAction(QStringLiteral("share_text_menu"), shareAction);
-        purposeMenu->setEditorWidget(this);
-        MessageComposer::PluginActionType type(shareAction, MessageComposer::PluginActionType::File);
-        setActionType(type);
     } else {
-        delete purposeMenu;
+        shareAction->setEnabled(false);
     }
 }
 
