@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -60,9 +60,9 @@ void EnterpriseHeaderStylePluginTest::testFormatEmpty()
 {
     MessageViewer::EnterpriseHeaderStylePlugin plugin;
     auto style = plugin.headerStyle();
-    auto stategy = plugin.headerStrategy();
-    style->setHeaderStrategy(stategy);
-    QCOMPARE(style->headerStrategy(), stategy);
+    auto strategy = plugin.headerStrategy();
+    style->setHeaderStrategy(strategy);
+    QCOMPARE(style->headerStrategy(), strategy);
     auto aMsg = new KMime::Message();
     testHeaderFile(style->format(aMsg), QStringLiteral("empty.enterprise"));
 }
@@ -84,9 +84,9 @@ void EnterpriseHeaderStylePluginTest::testFormat()
 
     MessageViewer::EnterpriseHeaderStylePlugin plugin;
     auto style = plugin.headerStyle();
-    auto stategy = plugin.headerStrategy();
-    style->setHeaderStrategy(stategy);
-    QCOMPARE(style->headerStrategy(), stategy);
+    auto strategy = plugin.headerStrategy();
+    style->setHeaderStrategy(strategy);
+    QCOMPARE(style->headerStrategy(), strategy);
     auto aMsg = readAndParseMail(mailbox);
     testHeaderFile(style->format(aMsg.data()), mailbox+QStringLiteral(".enterprise"));
 }
